/*
	LUSScreenSaver
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSScreenSaverMisc.h"
#include "LUSScreenSaver.h"
#include "LUSScreenSaverInterface.h"

using namespace LUSMisc;

LUSScreenSaver::LUSScreenSaver()
:m_pSaver(0), m_bForceExecuted(false)
{
}

LUSScreenSaver::~LUSScreenSaver()
{
}

void LUSScreenSaver::restore()
{
	DBG_LOG( "LUSScreenSaver::restore()" );

	SetLightLevel( GetLightLevel() );
	
	if ( m_pSaver )
	{
		LUSScreenSaverInterface* iface;
		if ( m_pSaver->queryInterface( IID_LUSScreenSaver, (QUnknownInterface**)&iface ) != QS_OK )
		{
			ExecOKDlg( "FATAL : Saver Can't Stop" );
			delete m_pSaver;
			m_pSaver = NULL;
			return;
		}
		iface->Stop();
		iface->release();
		m_pSaver->unload();
		delete m_pSaver;
		m_pSaver = NULL;
	}
}

bool LUSScreenSaver::save( int level )
{
	DBG_LOG( QString( "LUSScreenSaver::save( %1 )" ).arg( level ).latin1() );

	bool bRet = false;

	if ( m_bForceExecuted )
	{
		QWSServer::setScreenSaverInterval( GetLUSInterval() );
		m_bForceExecuted = false;
	}

	switch( level )
	{
	case 0:
		{
			if ( !IsSuspendFirst() )
			{
				if ( IsACOnline() )
				{
					bRet = ShowScreenSaver();
					break;
				}
				if ( IsDimEnable() )
				{
					SetLightLevel( GetDimLevel() );
					bRet = true;
					break;
				}
			}
		}
	case 1:
		{
			Global::execute( "suspend" );
		}
	case 2:
	default:
		break;
	}
	return bRet;
}

bool LUSScreenSaver::ShowScreenSaver()
{
	DBG_LOG( "LUSScreenSaver::ShowScreenSaver()" );
	if ( m_pSaver )
	{
		return true;
	}
	
	QString sSaverName = GetSaverName();
	if ( sSaverName.isEmpty() )
	{
		return false;
	}

	QString sSaverPath = AbsSaverPath( sSaverName );

	if ( !QFile::exists( sSaverPath ) )
	{
		ExecOKDlg( QString("\"%1\" Not Found" ).arg( sSaverName ) );
		return false;
	}

	DBG_LOG( "LUSScreenSaver::ShowScreenSaver() > Module loading start" );
	m_pSaver = new QLibrary( sSaverPath, QLibrary::Immediately );

    LUSScreenSaverInterface* iface;
    if ( m_pSaver->queryInterface( IID_LUSScreenSaver, (QUnknownInterface**)&iface ) != QS_OK )
	{
		delete m_pSaver;
		m_pSaver = NULL;
		ExecOKDlg( QString("\"%1\" Loading Failure" ).arg( sSaverName ) );
		return false;
	}

	QWidget* pSaverWidget = iface->Init( LUSScreenSaverInterface::LUS_NORMAL );

	if ( pSaverWidget )
	{
		DBG_LOG( "LUSScreenSaver::ShowScreenSaver() > widget->showFullScreen()" );
		pSaverWidget->showFullScreen();
	}
	
	iface->Start();
	DBG_LOG( "LUSScreenSaver::ShowScreenSaver() > Module Start" );

	return true;
}

void LUSScreenSaver::SetForceExecFlag()
{
	m_bForceExecuted = true;
}

int LUSScreenSaver::ExecOKDlg( const char* msg )
{
	return LUSScreenSaver::ExecBaseDlg(
					msg,
					QMessageBox::Ok | QMessageBox::Default | QMessageBox::Escape );
}

int LUSScreenSaver::ExecYesNoDlg( const char* msg )
{
	return LUSScreenSaver::ExecBaseDlg(
					msg,
					QMessageBox::Yes | QMessageBox::Default | QMessageBox::Escape,
					QMessageBox::No | QMessageBox::Escape );
}

int LUSScreenSaver::ExecBaseDlg( const char* msg, int button1, int button2 )
{
	QMessageBox mb( AppName(),
					msg,
					QMessageBox::NoIcon,
					button1,
					button2, QMessageBox::NoButton, TaskBarWidget() );
	mb.setIconPixmap( Resource::loadPixmap( "LUSScreenSaver_about" ) );
	mb.adjustSize();

	QPoint oDSize( QPEApplication::desktop()->width(),
					QPEApplication::desktop()->height() );
	QPoint oASize( mb.width(), mb.height() );
	mb.move( ( oDSize -  oASize ) / 2 );

	return mb.exec();
}
