/*
	LUSScreenSaver
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSScreenSaverMisc.h"

static QWidget*	g_pWidget		=	0;
static const QString	g_sDefSaverLibPath	=	"/opt/QtPalmtop/plugins/screensaver";

QString& LUSMisc::AppName()
{
	static QString sAppName = "LUSScreenSaver";
	return sAppName;
}

void LUSMisc::InitWidget( QWidget* widget )
{
	g_pWidget = widget;
}

QWidget* LUSMisc::TaskBarWidget()
{
	return g_pWidget;
}

int LUSMisc::GetLightLevel()
{
	Config cfg( "qpe" );
	cfg.setGroup( "Screensaver" );

	if ( IsACOnline() )
	{
		return cfg.readNumEntry( "Brightness_AC", 255 );
	}
	else
	{
		return cfg.readNumEntry( "Brightness", 50 );
	}
}

int LUSMisc::GetLUSInterval()
{
	Config cfg( "qpe" );
	cfg.setGroup( "Screensaver" );

	if ( IsACOnline() )
	{
		return cfg.readNumEntry( "Interval_AC_ScreenSaver", 300 ) * 1000;
	}
	else
	{
		return cfg.readNumEntry( "Interval_Dim", 10 ) * 1000;
	}
}

int LUSMisc::GetDimLevel()
{
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "Screensaver" );
	return cfg.readNumEntry( "Brightness_Dim", 1 );
}

void LUSMisc::SetLightLevel( const int bright )
{
	QCopEnvelope e( "QPE/System", "setBacklight(int)" );
	e << bright;
}

bool LUSMisc::IsACOnline()
{
	if ( PowerStatusManager::readStatus().acStatus()
								== PowerStatus::Online )
	{
		return true;
	}
	else
	{
		return false;
	}
}

bool LUSMisc::IsDimEnable()
{
	bool bRet;
	Config cfg( "qpe" );
	cfg.setGroup( "Screensaver" );
	bRet = cfg.readBoolEntry( "Dim" );
	
	return bRet;
}

QString LUSMisc::GetSaverName()
{
	QString sName;
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "Screensaver" );
	sName = cfg.readEntry( "Module" );
	
	return sName;
}

QString LUSMisc::AbsSaverPath( const QString& name )
{
	QString sConfigPath = LUSMisc::GetSaverLibPath();
	QString sPath = QString( "%1/lib%2.so" )
							.arg( sConfigPath.isEmpty() ? g_sDefSaverLibPath : sConfigPath )
							.arg( name );
	return sPath;
}

QString LUSMisc::GetSaverLibPath()
{
	QString sPath;
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "Screensaver" );
	sPath = cfg.readEntry( "ModulePath" );
	
	return sPath;
}

int LUSMisc::GetIconMode()
{
	QString sPath;
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "Misc" );
	return cfg.readNumEntry( "Icon", 1 );
}

void LUSMisc::SaveIconMode( int mode )
{
	QString sPath;
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "Misc" );
	cfg.writeEntry( "Icon", mode );
}

bool LUSMisc::IsSuspendFirst()
{
	Config cfg( "qpe" );
	cfg.setGroup( "Screensaver" );
	
	int nSuspend, nScreenSave;
	if ( IsACOnline() )
	{
		int nIdx = cfg.readNumEntry( "Interval_AC_idx" );
		QString sIdxKey;
		sIdxKey.sprintf( "Interval_AC_%02d", nIdx );
		nSuspend = cfg.readNumEntry( sIdxKey );
		nScreenSave = cfg.readNumEntry( "Interval_AC_ScreenSaver" );
	}
	else
	{
		nSuspend = cfg.readNumEntry( "Interval" );
		nScreenSave = cfg.readNumEntry( "Interval_Dim" );
	}
	return ( nSuspend <= nScreenSave ) ? TRUE : FALSE;
}
